import { ConflictException, Injectable } from '@nestjs/common';
import { InjectRepository } from '@nestjs/typeorm';
import { Repository } from 'typeorm';
import { Modelo } from './entity/modelo.entity';

@Injectable()
export class ModeloService {
  constructor(
    @InjectRepository(Modelo) private repository: Repository<Modelo>,
  ) {}

  create(modelo: string, tipo: string): Promise<{ message: string }> {
    // Buscamos un registro con ese nombre
    return this.findByModelo(modelo, tipo)
      .then((existeModelo) => {
        // Sacamos error si existe
        if (existeModelo) throw new ConflictException('Ya existe este modelo.');
        // Creamos y guardamos un registro
        return this.repository.save(this.repository.create({ modelo, tipo }));
      })
      .then((_) => ({ message: 'Se creó correctamente un nuevo modelo.' }));
  }

  findAll(tipo: string): Promise<Modelo[]> {
    return this.repository.find({ where: { tipo }, order: { tipo: 'ASC' } });
  }

  findById(id_modelo: number, tipo: string): Promise<Modelo> {
    return this.repository
      .findOne({ where: { id_modelo, tipo } })
      .then((modelo) => {
        if (!modelo) throw new ConflictException('No existe este modelo.');
        return modelo;
      });
  }

  findByModelo(modelo: string, tipo: string): Promise<Modelo> {
    return this.repository.findOne({ where: { modelo, tipo } });
  }
}
