import { DataSource, ViewEntity, ViewColumn } from 'typeorm';
import { Carrito } from '../../../carrito/entity/carrito.entity';
import { Equipo } from '../../../equipo/entity/equipo.entity';
import { InstitucionUsuario } from '../../../institucion-usuario/entity/institucion-usuario.entity';
import { Modulo } from '../../../modulo/entity/modulo.entity';
import { Prestamo } from '../prestamo.entity';
import { Status } from '../../../status/entity/status.entity';
import { TipoCarrito } from '../../../institucion-tipo-carrito/entity/tipo-carrito.entity';

@ViewEntity({
  expression: (dataSource: DataSource) =>
    dataSource
      .createQueryBuilder()
      .select('p.id_prestamo', 'id_prestamo')
      .addSelect('p.activo', 'activo')
      .addSelect('p.cancelado_operador', 'cancelado_operador')
      .addSelect('p.cancelado_usuario', 'cancelado_usuario')
      .addSelect('p.fecha_entrega', 'fecha_entrega')
      .addSelect('p.fecha_inicio', 'fecha_inicio')
      .addSelect('p.hora_fin', 'hora_fin')
      .addSelect('p.hora_inicio', 'hora_inicio')
      .addSelect('p.hora_max_recoger', 'hora_max_recoger')
      .addSelect('p.id_equipo', 'id_equipo')
      .addSelect('p.id_institucion_usuario', 'id_institucion_usuario')
      .addSelect('p.id_operador_entrega', 'id_operador_entrega')
      .addSelect('p.id_operador_regreso', 'id_operador_regreso')
      .addSelect('e.equipo', 'equipo')
      .addSelect('e.id_carrito', 'id_carrito')
      .addSelect('e.id_status', 'id_status')
      .addSelect('e.numero_inventario', 'numero_inventario')
      .addSelect('e.u', 'u')
      .addSelect('iu.id_institucion_carrera', 'id_institucion_carrera')
      .addSelect('iu.id_usuario', 'id_usuario')
      .addSelect('c.carrito', 'carrito')
      .addSelect('c.id_modulo', 'id_modulo')
      .addSelect('c.id_tipo_carrito', 'id_tipo_carrito')
      .addSelect('m.id_institucion', 'id_institucion')
      .addSelect('tc.tipo_carrito', 'tipo_carrito')
      .from(Prestamo, 'p')
      .innerJoin(Equipo, 'e', 'e.id_equipo = p.id_equipo')
      .innerJoin(
        InstitucionUsuario,
        'iu',
        'iu.id_institucion_usuario = p.id_institucion_usuario',
      )
      .innerJoin(Carrito, 'c', 'c.id_carrito = e.id_carrito')
      .innerJoin(Status, 's', 's.id_status = e.id_status')
      .innerJoin(Modulo, 'm', 'm.id_modulo = c.id_modulo')
      .innerJoin(TipoCarrito, 'tc', 'tc.id_tipo_carrito = c.id_tipo_carrito'),
})
export class InformacionPrestamoView {
  @ViewColumn()
  id_prestamo: number;

  @ViewColumn()
  activo: number;

  @ViewColumn()
  cancelado_operador: number;

  @ViewColumn()
  cancelado_usuario: number;

  @ViewColumn()
  carrito: string;

  @ViewColumn()
  equipo: string;

  @ViewColumn()
  fecha_entrega: Date;

  @ViewColumn()
  fecha_inicio: Date;

  @ViewColumn()
  hora_fin: Date;

  @ViewColumn()
  hora_inicio: Date;

  @ViewColumn()
  hora_max_recoger: Date;

  @ViewColumn()
  id_carrito: number;

  @ViewColumn()
  id_equipo: number;

  @ViewColumn()
  id_institucion: number;

  @ViewColumn()
  id_institucion_carrera: number;

  @ViewColumn()
  id_institucion_usuario: number;

  @ViewColumn()
  id_modulo: number;

  @ViewColumn()
  id_operador_entrega: number;

  @ViewColumn()
  id_operador_regreso: number;

  @ViewColumn()
  id_status: number;

  @ViewColumn()
  id_tipo_carrito: number;

  @ViewColumn()
  id_usuario: number;

  @ViewColumn()
  numero_inventario: string;

  @ViewColumn()
  tipo_carrito: string;

  @ViewColumn()
  u: number;
}
